@@ -11,17 +11,17 @@
 #'  Inserts relevant \code{expect_*} tests based
 #'  on the evaluation of the selected code.
 #'
-#'  Example: If the selected code is the name of a data frame object,
-#'  it will create an \code{\link[testthat:expect_equal]{expect_equal}}
+#'  Example: If the selected code is the name of a \code{data.frame} object,
+#'  it will create an \code{\link[testthat:equality-expectations]{expect_equal}}
 #'  test for each column,
 #'  along with a test of the column names.
 #'
-#'  Currently supports side effects (error, warnings, messages),
-#'  data frames, and vectors.
+#'  Currently supports side effects (\code{error}, \code{warning}s, \code{message}s),
+#'  \code{data.frame}s, and \code{vector}s.
 #'
-#'  List columns in data frames (like nested tibbles) are currently skipped.
+#'  List columns in \code{data.frame}s (like nested \code{tibble}s) are currently skipped.
 #'
-#'  See \code{Details} for how to set a key command.
+#'  See \code{`Details`} for how to set a key command.
 #' @param selection String of code. (Character)
 #'
 #'  E.g. \code{"stop('This gives an expect_error test')"}.
@@ -31,22 +31,23 @@
 #'
 #'  \strong{N.B.} Mainly intended for testing the addin programmatically.
 #' @param insert Whether to insert the expectations via
-#'  \code{\link[rstudioapi:insertText]{rstudioapi::insertText()}}
+#'  \code{\link[rstudioapi:rstudio-documents]{rstudioapi::insertText()}}
 #'  or return them. (Logical)
 #'
 #'  \strong{N.B.} Mainly intended for testing the addin programmatically.
+#' @inheritParams gxs_selection
 #' @author Ludvig Renbo Olsen, \email{r-pkgs@@ludvigolsen.dk}
 #' @family expectation generators
 #' @family addins
 #' @export
-#' @return Inserts \code{\link[testthat:expect_equal]{testthat::expect_*}}
+#' @return Inserts \code{\link[testthat:equality-expectations]{testthat::expect_*}}
 #'  unit tests for the selected code.
 #'
 #'  Returns \code{NULL} invisibly.
 #' @details
 #'  \subsection{How}{
 #'  Parses and evaluates the selected code string
-#'  within the parent environment.
+#'  within the parent environment (or a deep copy thereof).
 #'  Depending on the output, it creates a set of unit tests
 #'  (like \code{expect_equal(data[["column"]], c(1,2,3))}),
 #'  and inserts them instead of the selection.
@@ -70,13 +71,14 @@
 #' @importFrom rlang := .data
 #' @importFrom dplyr %>%
 #' @importFrom stats runif
-insertExpectationsAddin <- function(selection = NULL, insert = TRUE, indentation = 0) {
+insertExpectationsAddin <- function(selection = NULL, insert = TRUE, indentation = 0, copy_env = FALSE) {
 
   # Check arguments ####
   assert_collection <- checkmate::makeAssertCollection()
   checkmate::assert_string(x = selection, null.ok = TRUE,
                            add = assert_collection)
   checkmate::assert_flag(x = insert, add = assert_collection)
+  checkmate::assert_flag(x = copy_env, add = assert_collection)
   checkmate::assert_integerish(x = indentation, lower = 0,
                                any.missing = FALSE,
                                null.ok = TRUE,
@@ -109,7 +111,8 @@ insertExpectationsAddin <- function(selection = NULL, insert = TRUE, indentation
 
     generator <- function(out){
       gxs_selection(selection, indentation = indentation,
-                    envir = parent_envir, out = out)
+                    envir = parent_envir, out = out,
+                    copy_env = copy_env)
     }
 
     if (!isTRUE(insert)) {
@@ -124,3 +127,14 @@ insertExpectationsAddin <- function(selection = NULL, insert = TRUE, indentation
 
   invisible()
 }
+
+#' @rdname insertExpectationsAddin
+#' @export
+insertExpectationsCopyEnvAddin <- function(selection = NULL, insert = TRUE, indentation = 0, copy_env = TRUE){
+  insertExpectationsAddin(
+    selection = selection,
+    insert = insert,
+    indentation = indentation,
+    copy_env = copy_env
+  )
+}
